summaryrefslogtreecommitdiff
path: root/community/cinnamon/set_wheel.patch
blob: 372308342becdee972b08a4cb6a639592c3d7909 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
--- a/files/usr/lib/cinnamon-settings-users/cinnamon-settings-users.py
+++ b/files/usr/lib/cinnamon-settings-users/cinnamon-settings-users.py
@@ -734,9 +734,9 @@ class Module:
             pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size("/usr/share/cinnamon/faces/user-generic.png", 48, 48)
             description = "<b>%s</b>\n%s" % (fullname, username)
             piter = self.users.append(None, [new_user, pixbuf, description])
             # Add the user to his/her own group and sudo if Administrator was selected
             if dialog.account_type_combo.get_active() == 1:
-                os.system("usermod %s -G %s,sudo" % (username, username)) 
+                os.system("usermod %s -G %s,wheel" % (username, username)) 
             else:
                 os.system("usermod %s -G %s" % (username, username))
             self.load_groups()
@@ -734,9 +734,9 @@ class Module:
             description = "<b>%s</b>\n%s" % (fullname, username)
             piter = self.users.append(None, [new_user, pixbuf, description])
-            # Add the user to his/her own group and sudo if Administrator was selected
+            # Add the user to his/her own group and wheel if Administrator was selected
             if dialog.account_type_combo.get_active() == 1: